pub type MatRef<'a, T, Rows = usize, Cols = usize, RStride = isize, CStride = isize> = Mat<Ref<'a, T, Rows, Cols, RStride, CStride>>;Expand description
immutable view over a matrix, similar to an immutable reference to a 2d strided slice
Note
unlike a slice, the data pointed to by MatRef<'_, T> is allowed to be
partially or fully uninitialized under certain conditions. in this case,
care must be taken to not perform any operations that read the uninitialized
values, either directly or indirectly through any of the numerical library
routines, unless it is explicitly permitted
Aliased Type
#[repr(transparent)]pub struct MatRef<'a, T, Rows = usize, Cols = usize, RStride = isize, CStride = isize>(pub Ref<'a, T, Rows, Cols, RStride, CStride>);Tuple Fields
0: Ref<'a, T, Rows, Cols, RStride, CStride>